@@ -132,11 +132,10 @@ MALLOC_DECLARE(M_NVIDIA);
 #define NV_SUPPORT_LINUX_COMPAT
 
 /*
- * Enable/Disable support for ACPI Power Management. This is untested and
- * thus disabled by default (this is 5.x/-CURRENT only).
+ * Enable/Disable support for ACPI Power Management.
  */
 
-#undef NV_SUPPORT_ACPI_PM
+#define NV_SUPPORT_ACPI_PM
 
 /*
  * Enable/Disable heavy-weight cache-flush logic. By default, the driver
