@@ -29,16 +29,20 @@ void nvidia_pci_identify(driver_t *driver, device_t parent)
 
 int nvidia_pci_probe(device_t dev)
 {
-    U016 device;
+    NvU16 device;
     char name[NV_DEVICE_NAME_LENGTH];
     nv_stack_t *sp;
+    NvU16 subvendor, subdevice;
+
+    device = pci_get_device(dev);
 
     if ((pci_get_class(dev) != PCIC_DISPLAY) ||
             ((pci_get_subclass(dev) != PCIS_DISPLAY_VGA) &&
              (pci_get_subclass(dev) != PCIS_DISPLAY_3D)) ||
             (pci_get_vendor(dev) != 0x10de) ||
-            ((device = pci_get_device(dev)) < 0x0020))
+            (device  < 0x0020)) {
         return ENXIO;
+    }
 
     NV_UMA_ZONE_ALLOC_STACK(sp);
     if (sp == NULL)
@@ -49,7 +53,11 @@ int nvidia_pci_probe(device_t dev)
         return ENXIO;
     }
 
-    if (rm_get_device_name(sp, NULL, device, NV_DEVICE_NAME_LENGTH, name)
+    subvendor = pci_get_subvendor(dev);
+    subdevice = pci_get_subdevice(dev);
+
+    if (rm_get_device_name(sp, NULL, device, subvendor, subdevice,
+                NV_DEVICE_NAME_LENGTH, name)
             != RM_OK) {
         strcpy(name, "Unknown");
     }
@@ -101,14 +109,14 @@ fail:
 
 static void nvidia_pci_disable_serr(device_t dev)
 {
-    U016 word;
+    NvU16 word;
     word = (os_pci_read_word(dev, PCIR_COMMAND) & ~PCIM_CMD_SERRESPEN);
     os_pci_write_word(dev, PCIR_COMMAND, word);
 }
 
 static void nvidia_pci_enable_intx(device_t dev)
 {
-    U016 word;
+    NvU16 word;
     word = (os_pci_read_word(dev, PCIR_COMMAND) & ~PCIM_CMD_INTXDIS);
     os_pci_write_word(dev, PCIR_COMMAND, word);
 }
@@ -121,8 +129,8 @@ void nvidia_pci_check_config_space(
     BOOL may_block
 )
 {
-    U032 BAR_low, BAR_high;
-    U016 word, i;
+    NvU32 BAR_low, BAR_high;
+    NvU16 word, i;
     struct nvidia_softc *sc = device_get_softc(dev);
     nv_state_t *nv = sc->nv_state;
 
@@ -172,10 +180,10 @@ void nvidia_pci_check_config_space(
     }
 }
 
-U008 nvidia_pci_find_capability(device_t dev, U008 capability)
+NvU8 nvidia_pci_find_capability(device_t dev, NvU8 capability)
 {
-    U016 status;
-    U008 cap_ptr, cap_id;
+    NvU16 status;
+    NvU8 cap_ptr, cap_id;
 
     status = pci_read_config(dev, PCIR_STATUS, 2);
     status &= PCIM_STATUS_CAPPRESENT;
@@ -208,8 +216,8 @@ int nvidia_pci_attach(device_t dev)
 {
     int status;
     struct nvidia_softc *sc;
-    U016 word, i, j;
-    U032 BAR_low, req;
+    NvU16 word, i, j;
+    NvU32 BAR_low, req;
     nv_stack_t *sp;
 
     if (device_get_unit(dev) >= NV_MAX_DEVICES) {
@@ -241,7 +249,7 @@ int nvidia_pci_attach(device_t dev)
     }
 
     for (i = 0, j = 0; i < NVRM_PCICFG_NUM_BARS && j < NV_GPU_NUM_BARS; i++) {
-        U008 offset = NVRM_PCICFG_BAR_OFFSET(i);
+        NvU8 offset = NVRM_PCICFG_BAR_OFFSET(i);
         BAR_low = os_pci_read_dword(dev, offset);
         os_pci_write_dword(dev, offset, 0xffffffff);
         req = os_pci_read_dword(dev, offset);
