@@ -170,7 +170,7 @@ int nvidia_suspend(device_t dev)
     int status;
 
     /* Only if ACPI is running */
-    if (devclass_get_softc(devclass_find("ACPI"), 0) == NULL)
+    if (devclass_get_softc(devclass_find("acpi"), 0) == NULL)
         return ENODEV;
 
     NV_UMA_ZONE_ALLOC_STACK(sp);
@@ -987,9 +987,9 @@ void NV_API_CALL nv_post_event(
     et->event.hObject = hObject;
     et->event.index = index;
 
-    mtx_lock_spin(&filep->event_mtx);
+    mtx_lock(&filep->event_mtx);
     STAILQ_INSERT_TAIL(&filep->event_queue, et, queue);
-    mtx_unlock_spin(&filep->event_mtx);
+    mtx_unlock(&filep->event_mtx);
 
     selwakeup(&filep->event_rsel);
 }
@@ -1004,7 +1004,7 @@ NvS32 NV_API_CALL nv_get_event(
     struct nvidia_filep *filep = file;
     struct nvidia_event *et;
 
-    mtx_lock_spin(&filep->event_mtx);
+    mtx_lock(&filep->event_mtx);
     et = STAILQ_FIRST(&filep->event_queue);
 
     if (et != NULL) {
@@ -1013,13 +1013,13 @@ NvS32 NV_API_CALL nv_get_event(
         STAILQ_REMOVE(&filep->event_queue, et, nvidia_event, queue);
         *pending = !STAILQ_EMPTY(&filep->event_queue);
 
-        mtx_unlock_spin(&filep->event_mtx);
+        mtx_unlock(&filep->event_mtx);
         free(et, M_NVIDIA);
 
         return RM_OK;
     }
 
-    mtx_unlock_spin(&filep->event_mtx);
+    mtx_unlock(&filep->event_mtx);
     return RM_ERROR;
 }
 
